import pandas as pd
import numpy as np
from haversine import haversine

def test():
    print("곽운일, 심명진, 김도영, 편도준")

def test2():
    t = pd.DataFrame(data=[1,2,3])
    display(t)

def t_csv(x,y,z):
    if y==40:
        x.to_csv('land40_{}.csv'.format(z),encoding='cp949')
    if y==4070:
        x.to_csv('land40_70_{}.csv'.format(z),encoding='cp949')
    if y==70:
        x.to_csv('land70_{}.csv'.format(z),encoding='cp949')

def make_distance(x,y,name):
    df = pd.DataFrame()
    
    for i in range(len(x)):
        for j in range(len(y)):
            distance = haversine(x.loc[:,['위도','경도']].values[i],
                                 y.loc[:,['위도','경도']].values[j],
                                 unit = 'km')
            if distance <= 1:
                new_data ={'아파트' : x['주소'].values[i],
                           '거리' : distance}
                df = df.append(new_data,ignore_index=True)
                
    df = df.groupby(['아파트']).agg(['count', 'mean']).reset_index()
    df.columns=['주소', name+' 개수', name+' 평균거리']
    apt_df = pd.merge(x, df, left_on = '주소', right_on = '주소', how = 'left')
    return apt_df


import setuptools

# with open('README.md', encoding='utf-8') as f: # README.md 내용 읽어오기
#         long_description = f.read()

setuptools.setup(
    name='rainod', # 패키지 명
    version='1.0.6',
    description='2조 패키지',
    author='dojun',
    author_email='ehwns4337@naver.com',
    url='',
    license='MIT', # MIT에서 정한 표준 라이센스 따른다
    #py_modules=['rb'], # 패키지에 포함되는 모듈
    python_requires='>=3',
    install_requires=[], # 패키지 사용을 위해 필요한 추가 설치 패키지
    packages=setuptools.find_packages(), # 패키지가 들어있는 폴더들
)